# Copyright (c) 2017-2021 Patricio Cubillos and contributors.
# repack is open-source software under the MIT license (see LICENSE).

# repack version:
repack_VER = 1  # Major version
repack_MIN = 4  # Minor version
repack_REV = '5a1'  # Revision

__version__ = f'{repack_VER}.{repack_MIN}.{repack_REV}'
